ewa.wsgiapp

Package ewa :: Module wsgiapp |
[hide private]
[frames] | no frames]

# Module wsgiapp

source code

A WSGI application that generates mp3s dynamically according to a ruleset.

Classes | [hide private]
| EwaApp

Functions | [hide private]
guess_mime(filename) | source code

Variables | [hide private]
| _codes = ``{`200`:` `'``200 OK``'``,` 404`:` `'``404 Not Found``'``,` 500`:` `'``500 Inter``...``
| GENERIC_SENDFILE_HEADER = ``'``X-Sendfile``'``
| LIGHTTPD_SENDFILE_HEADER = ``'``X-LIGHTTPD-send-file``'``
| MP3_MIMETYPE = ``'``audio/mpeg``'``
| __package__ = ``'``ewa``'``

Variables Details | [hide private]

  ### _codes Value:
      {200: '200 OK',
       404: '404 Not Found',
       500: '500 Internal Server Error'}